@@ -84,12 +84,12 @@ originize_dir <-
     use_markers =
       getOption("origin.use_markers_for_logging", TRUE)
   ) {
-
+    
     if (!check_base_conflicts && add_base_packages) {
       stop("When adding base packages checking for ",
            "potential conflicts is required!")
     }
-
+    
     files <- list_files(path = path,
                         exclude_folders = c("renv", "packrat",
                                             ".git", ".Rproj"),
@@ -98,8 +98,8 @@ originize_dir <-
                         recursive = recursive,
                         pattern = "\\.R$",
                         ignore.case = TRUE)
-
-
+    
+    
     # TODO: non absolute paths
     if (!is.null(exclude_files)) {
       if (any(!exclude_files %in% files)) {
@@ -108,43 +108,45 @@ originize_dir <-
       }
       files <- files[!files %in% exclude_files]
     }
-
-
+    
+    
     # warning if many files are about to be originized
     n_files <- length(files)
     if (n_files > 20) {
-      cat(sprintf("You are about to originize %s files.\nProceed?", n_files))
-      if (interactive()) {
-        answer <- utils::menu(choices = c("YES", "NO", "Show files")) # nocov
+      if (interactive() && ask_before_applying_changes) {
+        # nocov start
+        cat(sprintf("You are about to originize %s files.\nProceed?", n_files))
+        answer <- utils::menu(choices = c("YES", "NO", "Show files"))
+        # nocov end
       } else {
         answer <- 1
       }
-
+      
       if (answer == 2) {
-        stop("Execution halted") # nocov
+        # nocov start
+        stop("Execution halted")
       } else if (answer == 3) {
         print(files)
         cat("\nProceed?")
-        if (interactive()) {
-          answer2 <- utils::menu(choices = c("YES", "NO")) # nocov
-        } else {
-          answer2 <- 1
-        }
-
+        answer2 <- utils::menu(choices = c("YES", "NO"))
+        
         if (answer2 == 2) {
-          stop("Execution halted") # nocov
+          stop("Execution halted")
         }
       }
+      # nocov end
     }
-
+    
     # read file
     scripts <- suppressWarnings(lapply(files, readLines))
-
+    
     # check for empty scripts
     empty_scripts <- vapply(X = scripts,
-                            FUN = length,
-                            FUN.VALUE = integer(1)) == 0
-
+                            FUN = function(x) {
+                              length(x) == 0 || all(!nzchar(x))
+                            },
+                            FUN.VALUE = logical(1))
+    
     if (all(empty_scripts)) {
       message("All provided scripts are empty")
       return(invisible(NULL))
@@ -152,7 +154,7 @@ originize_dir <-
       scripts <- scripts[!empty_scripts]
       files <- files[!empty_scripts]
     }
-
+    
     originize_wrap(scripts = scripts,
                    files = files,
                    type = "writeLines",
@@ -167,7 +169,7 @@ originize_dir <-
                    use_markers = use_markers,
                    path_to_local_functions = path_to_local_functions,
                    check_local_conflicts = check_local_conflicts)
-
+    
     return(invisible(NULL))
-
+    
   }
